#!/usr/bin/env python

import os
import textwrap
from waflib.TaskGen import before_method, extension, feature

def dedent(s):
    return textwrap.dedent(s.strip("\n")).strip("\n")

def _sdk(version):
    flags = [
        "-isysroot",
        ("/Applications/Xcode.app/Contents/Developer/Platforms"
         "/MacOSX.platform/Developer/SDKs/MacOSX%s.sdk") % version,
        "-mmacosx-version-min=%s" % version,
    ]
    return {
        "CFLAGS": flags,
        "CXXFLAGS": flags,
        "LINKFLAGS": flags,
        "UNIVERSAL_ARCHES": ["i386", "x86_64"],
    }

ARCH = ["i386", "x86_64"]
SDKS = ["10.7", "10.8", "10.9"]

COMPILER = {
    "CC": "clang",
    "CXX": "clang++",
    "LINK_CC": "clang",
    "LINK_CXX": "clang++",
}

def options(opt):
    if not hasattr(opt, "default_sdk"):
        raise opt.errors.ConfigurationError("must set default_sdk")

    if hasattr(opt, "platform_darwin_initialized"):
        return
    else:
        opt.platform_darwin_initialized = True

    opt.add_option(
            "--sdk", action="store", default=opt.default_sdk, choices=SDKS,
            help="Compile against this SDK on darwin.  [default: %r]" % opt.default_sdk)
    opt.add_option(
            "--arch", action="append", default=[], choices=ARCH,
            help=dedent("""
                Append to the list of architectures to build.  Individual targets may not build
                on the specified architecture.  [default: i386, x86_64]
            """))

def configure(cnf):
    for key, val in _sdk(cnf.options.sdk).items():
        if isinstance(val, list):
            cnf.env.append_unique(key, val)
        else:
            cnf.env[key] = val

    for key, val in COMPILER.items():
        if isinstance(val, list):
            cnf.env.append_unique(key, val)
        else:
            cnf.env[key] = val


@feature("universal")
@before_method("process_source")
def build_universal(self):
    self.env.ARCH = self.bld.env["UNIVERSAL_ARCHES"]


@feature("universal32")
@before_method("process_source")
def build_universal32(self):
    self.env.ARCH = [a for a in self.bld.env["UNIVERSAL_ARCHES"] if a in ["ppc", "i386"]]
    if not self.env.ARCH:
        raise self.bld.errors.ConfigurationError(
                "%s can only be built 32-bit" % self.target)


@extension(".m")
def m_hook(self, node):
    "Bind the m file extension to the same rules as c"
    return self.create_compiled_task("c", node)


@extension(".mm")
def m_hook(self, node):
    "Bind the mm file extension to the same rules as cxx"
    return self.create_compiled_task("cxx", node)
